public inbox for gentoo-commits@lists.gentoo.org
 help / color / mirror / Atom feed
* [gentoo-commits] gentoo-x86 commit in dev-python/django/files: django-1.2.3-fix_tests.patch
@ 2010-09-22 19:38 Arfrever Frehtes Taifersar Arahesis (arfrever)
  0 siblings, 0 replies; 2+ messages in thread
From: Arfrever Frehtes Taifersar Arahesis (arfrever) @ 2010-09-22 19:38 UTC (permalink / raw
  To: gentoo-commits

arfrever    10/09/22 19:38:30

  Added:                django-1.2.3-fix_tests.patch
  Log:
  Version bump. Fixed CVE-2010-3082 (bug #336594). Improve pysqlite dependencies (bug #334801). Fixed building with Sphinx 1.0 (bug #331689).
  
  (Portage version: 2.2_rc86_p1/cvs/Linux x86_64)

Revision  Changes    Path
1.1                  dev-python/django/files/django-1.2.3-fix_tests.patch

file : http://sources.gentoo.org/viewvc.cgi/gentoo-x86/dev-python/django/files/django-1.2.3-fix_tests.patch?rev=1.1&view=markup
plain: http://sources.gentoo.org/viewvc.cgi/gentoo-x86/dev-python/django/files/django-1.2.3-fix_tests.patch?rev=1.1&content-type=text/plain

Index: django-1.2.3-fix_tests.patch
===================================================================
http://code.djangoproject.com/changeset/13750
http://code.djangoproject.com/changeset/13764

--- tests/regressiontests/admin_views/tests.py
+++ tests/regressiontests/admin_views/tests.py
@@ -2206,16 +2206,19 @@
             self.assertContains(response, "<h2>Built-in tags</h2>", count=2)
 
             # A builtin tag exists in both the index and detail
-            self.assertContains(response, '<h3 id="autoescape">autoescape</h3>')
-            self.assertContains(response, '<li><a href="#autoescape">autoescape</a></li>')
+            self.assertContains(response, '<h3 id="built_in-autoescape">autoescape</h3>')
+            self.assertContains(response, '<li><a href="#built_in-autoescape">autoescape</a></li>')
 
             # An app tag exists in both the index and detail
-            # The builtin tag group exists
+            self.assertContains(response, '<h3 id="comments-get_comment_count">get_comment_count</h3>')
+            self.assertContains(response, '<li><a href="#comments-get_comment_count">get_comment_count</a></li>')
+
+            # The admin list tag group exists
             self.assertContains(response, "<h2>admin_list</h2>", count=2)
 
-            # A builtin tag exists in both the index and detail
-            self.assertContains(response, '<h3 id="autoescape">autoescape</h3>')
-            self.assertContains(response, '<li><a href="#admin_actions">admin_actions</a></li>')
+            # An admin list tag exists in both the index and detail
+            self.assertContains(response, '<h3 id="admin_list-admin_actions">admin_actions</h3>')
+            self.assertContains(response, '<li><a href="#admin_list-admin_actions">admin_actions</a></li>')
 
         def test_filters(self):
             response = self.client.get('/test_admin/admin/doc/filters/')
@@ -2224,8 +2227,8 @@
             self.assertContains(response, "<h2>Built-in filters</h2>", count=2)
 
             # A builtin filter exists in both the index and detail
-            self.assertContains(response, '<h3 id="add">add</h3>')
-            self.assertContains(response, '<li><a href="#add">add</a></li>')
+            self.assertContains(response, '<h3 id="built_in-add">add</h3>')
+            self.assertContains(response, '<li><a href="#built_in-add">add</a></li>')
 
 except ImportError:
     pass






^ permalink raw reply	[flat|nested] 2+ messages in thread
* [gentoo-commits] gentoo-x86 commit in dev-python/django/files: django-1.2.3-fix_tests.patch
@ 2011-01-26 20:08 Arfrever Frehtes Taifersar Arahesis (arfrever)
  0 siblings, 0 replies; 2+ messages in thread
From: Arfrever Frehtes Taifersar Arahesis (arfrever) @ 2011-01-26 20:08 UTC (permalink / raw
  To: gentoo-commits

arfrever    11/01/26 20:08:19

  Removed:              django-1.2.3-fix_tests.patch
  Log:
  Delete older ebuilds.
  
  (Portage version: 2.2.0_alpha19_p2/cvs/Linux x86_64)



^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2011-01-26 20:09 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2010-09-22 19:38 [gentoo-commits] gentoo-x86 commit in dev-python/django/files: django-1.2.3-fix_tests.patch Arfrever Frehtes Taifersar Arahesis (arfrever)
  -- strict thread matches above, loose matches on Subject: below --
2011-01-26 20:08 Arfrever Frehtes Taifersar Arahesis (arfrever)

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox